@@ -1,4 +1,5 @@
 export const DEFAULT_GLOB_PATTERN = '**/*@(.sh|.inc|.bash|.command)'
+export const DEFAULT_BACKGROUND_ANALYSIS_MAX_FILES = 500
 
 export function getShellcheckPath(): string | null {
   const { SHELLCHECK_PATH } = process.env
@@ -13,6 +14,9 @@ export function getExplainshellEndpoint(): string | null {
     : null
 }
 
+/**
+ * Get the glob pattern for files to run background analysis on.
+ */
 export function getGlobPattern(): string {
   const { GLOB_PATTERN } = process.env
   return typeof GLOB_PATTERN === 'string' && GLOB_PATTERN.trim() !== ''
@@ -23,6 +27,17 @@ export function getGlobPattern(): string {
 export function getHighlightParsingError(): boolean {
   const { HIGHLIGHT_PARSING_ERRORS } = process.env
   return typeof HIGHLIGHT_PARSING_ERRORS !== 'undefined'
-    ? HIGHLIGHT_PARSING_ERRORS === 'true' || HIGHLIGHT_PARSING_ERRORS === '1'
+    ? toBoolean(HIGHLIGHT_PARSING_ERRORS)
     : false
 }
+
+/**
+ * Get the maximum number of files to run background analysis on.
+ */
+export function getBackgroundAnalysisMaxFiles(): number {
+  const { BACKGROUND_ANALYSIS_MAX_FILES } = process.env
+  const parsed = parseInt(BACKGROUND_ANALYSIS_MAX_FILES || '', 10)
+  return !isNaN(parsed) ? parsed : DEFAULT_BACKGROUND_ANALYSIS_MAX_FILES
+}
+
+const toBoolean = (s: string): boolean => s === 'true' || s === '1'
