@@ -8,7 +8,7 @@ import Analyzer from './analyser'
 import * as Builtins from './builtins'
 import * as config from './config'
 import Executables from './executables'
-import { getLinterExecutablePath, Linter } from './linter'
+import { Linter } from './linter'
 import { initializeParser } from './parser'
 import * as ReservedWords from './reservedWords'
 import { BashCompletionItem, CompletionItemDataType } from './types'
@@ -30,21 +30,40 @@ export default class BashServer {
     connection: LSP.Connection,
     { rootPath, capabilities }: LSP.InitializeParams,
   ): Promise<BashServer> {
-    const parser = await initializeParser()
-
     const { PATH } = process.env
 
     if (!PATH) {
       throw new Error('Expected PATH environment variable to be set')
     }
 
-    return Promise.all([
-      Executables.fromPath(PATH),
-      Analyzer.fromRoot({ connection, rootPath, parser }),
-      getLinterExecutablePath(),
-    ]).then(([executables, analyzer, linterExecutablePath]) => {
-      const linter = new Linter({ executablePath: linterExecutablePath })
-      return new BashServer(connection, executables, analyzer, linter, capabilities)
+    const parser = await initializeParser()
+    const analyzer = new Analyzer({ console: connection.console, parser })
+
+    let backgroundAnalysisCompleted
+    if (rootPath) {
+      // NOTE: we do not block the server initialization on this background analysis.
+      backgroundAnalysisCompleted = analyzer.initiateBackgroundAnalysis({ rootPath })
+    }
+
+    const shellcheckPath = config.getShellcheckPath()
+    const linter = new Linter({
+      console: connection.console,
+      executablePath: shellcheckPath,
+    })
+
+    if (!shellcheckPath) {
+      connection.console.info('ShellCheck linting is disabled.')
+    }
+
+    const executables = await Executables.fromPath(PATH)
+
+    return new BashServer({
+      analyzer,
+      backgroundAnalysisCompleted,
+      capabilities,
+      connection,
+      executables,
+      linter,
     })
   }
 
@@ -55,19 +74,29 @@ export default class BashServer {
   private documents: LSP.TextDocuments<TextDocument> = new LSP.TextDocuments(TextDocument)
   private connection: LSP.Connection
   private clientCapabilities: LSP.ClientCapabilities
+  public backgroundAnalysisCompleted?: Promise<any>
 
-  private constructor(
-    connection: LSP.Connection,
-    executables: Executables,
-    analyzer: Analyzer,
-    linter: Linter,
-    capabilities: LSP.ClientCapabilities,
-  ) {
+  private constructor({
+    connection,
+    executables,
+    analyzer,
+    linter,
+    capabilities,
+    backgroundAnalysisCompleted,
+  }: {
+    connection: LSP.Connection
+    executables: Executables
+    analyzer: Analyzer
+    linter: Linter
+    capabilities: LSP.ClientCapabilities
+    backgroundAnalysisCompleted?: Promise<any>
+  }) {
     this.connection = connection
     this.executables = executables
     this.analyzer = analyzer
     this.linter = linter
     this.clientCapabilities = capabilities
+    this.backgroundAnalysisCompleted = backgroundAnalysisCompleted
   }
 
   /**
@@ -292,7 +321,7 @@ export default class BashServer {
     if (!word) {
       return null
     }
-    return this.analyzer.findDefinition(word)
+    return this.analyzer.findDefinition({ word })
   }
 
   private onDocumentSymbol(params: LSP.DocumentSymbolParams): LSP.SymbolInformation[] {
